/**
 * UT统计入口类
 * @author daichenjie
 * <pre>
 * 发送打点，首先需要获取一个UTTracker实例。
 * 
 * 获取UTTracker打点实例的方式有2种途径：
 *    1)通过UTAnalytics.getInstance().getDefaultTracker.
 *    2)通过UTAnalytics.getInstance().getTracker(String aTrackId)
 *    
 * 这里TrackId是一个什么概念呢？
 *    1)独立的Tracker共享defaultTracker的基础数据，如appkey，channel，用户帐号，设备信息等，你
 *    	可以认为独立的Tracker就多了一个TrackId，其它的一致。
 *    2)所有Tracker打出来的数据，我们会在reserves字段中，增加_tkid=TrackId值这个内容，用来和
 *    	defaultTracker的数据做一个区别
 *    
 * 那么，怎么完成一个打点呢？(下面以一个播放音乐自定义事件为例)
 * 
 *    1)通过defaultTracker打点
 *         //构造打点的map
 *         UTCustomHitBuilder lHitBuilder = new UTHitBuilders.UTCustomHitBuilder(
 *				"play_music");
 *         lHitBuilder.setProperty("type", "rock");
 *         lHitBuilder.setProperty("title", "wonderful tonight");
 *         //通过defaultTracker发送打点
 *         UTAnalytics.getInstance().getDefaultTracker().send(lHitBuilder.build());
 *
 *    2)通过独立的Tracker打点
 *         //构造打点的map
 *         UTCustomHitBuilder lHitBuilder = new UTHitBuilders.UTCustomHitBuilder(
 *				"play_music");
 *         lHitBuilder.setProperty("type", "rock");
 *         lHitBuilder.setProperty("title", "wonderful tonight");
 *         //通过独立Tracker发送打点
 *         UTTracker lTracker = UTAnalytics.getInstance().getTracker("your track id");
 *         lTracker.send(lHitBuilder.build());
 *</pre>
 */
public class UTAnalytics {
/**
	 * 设置SDK执行需要的Context
	 * @param aContext
	 */
	public void setContext(Context aContext) {
}
/**
	 * 设置Application实例，完成4.0以上自动页面以及应用使用时长运算
	 * @param aApplicationInstance 若没有Application实例，那么需要用ApplicationContext代替
	 * 
	 */
	public void setAppApplicationInstance(Application aApplicationInstance) {
}
/**
	 * 获取UTAnalytics实例
	 * @return 需要先调用setRequestAuthentication设置签名验证方式，返回的值才不为null
	 */
	public synchronized static UTAnalytics getInstance() {
}
/**
	 * 获取默认埋点实例
	 * @return
	 */
	public synchronized UTTracker getDefaultTracker() {
}
/**
	 * 设置SDK发送请求验证类型
	 * @param aRequestAuthenticationInstance 不能为null，设置失败会导致服务端拒绝数据
	 */
	public void setRequestAuthentication(
			IUTRequestAuthentication aRequestAuthenticationInstance) {
}
/**
	 * 设置应用版本，如果xml中的versionname不能满足需求(关联报表指标：app版本维度)
	 * @param aAppVersion
	 */
	public void setAppVersion(String aAppVersion) {
}
/**
	 * 获取更多的埋点实例（可以理解为插件的模式）
	 * @param aTrackId	实例ID（例如：插件ID）
	 * @return
	 */
	public synchronized UTTracker getTracker(String aTrackId) {
}
/**
	 * 设置渠道，如91(关联报表指标：渠道统计)
	 * @param aChannel
	 */
	public void setChannel(String aChannel) {
}
/**
	 * 关闭crash采集
	 */
	public void turnOffCrashHandler() {
}
/**
	 * 设置crash触发之后，回调通知
	 * @param aListener
	 */
	public void setCrashCaughtListener(IUTCrashCaughtListner aListener) {
}
/**
	 * 打开调试log显示
	 */
	public void turnOnDebug() {
}
/**
	 * 更新用户账号信息(关联报表指标：活跃用户数)
	 * @param aUsernick	昵称
	 * @param aUserid	数字ID
	 */
	public void updateUserAccount(String aUsernick, String aUserid) {
}
/**
	 * 发送用户注册事件(关联报表指标：注册用户数)
	 * 
	 * @param aUsernick
	 *            用户昵称
	 */
	public void userRegister(String aUsernick) {
}
/**
	 * 更新session信息,传入的信息会在每条日志的reserves字段携带
	 * session信息清除逻辑:应用切后台超过30秒再进入前台会清除之前的session信息
	 * @param aMap
	 *            session信息
	 */
	public void updateSessionProperties(Map<String,String> aMap){
}

}
