/**
 * UT打点辅助类的容器类
 * @author daichenjie
 * <pre>
 * 内部的子类的使命都在构造最完美的打点数据结构体。
 * 
 * UTPageHitBuilder：页面打点
 * UTCustomeHitBuilder：自定义事件打点
 * </pre>
 */
public class UTHitBuilders {
/**
	 * 打点基类，不建议直接使用
	 * @author daichenjie
	 *
	 */
	public static class UTHitBuilder {
public final static String FIELD_PAGE = "_field_page";
		public final static String FIELD_EVENT_ID = "_field_event_id";
		public final static String FIELD_ARG1 = "_field_arg1";
		public final static String FIELD_ARG2 = "_field_arg2";
		public final static String FIELD_ARG3 = "_field_arg3";
		public final static String FIELD_ARGS = "_field_args";

		private Map<String, String> mHitMap = new HashMap<String, String>();

		public UTHitBuilder() {
}
/**
		 * 给打点添加属性对
		 * @param aKey		key，不能为空和null
		 * @param aValue	value，不能为null
		 * @return
		 */
		public UTHitBuilder setProperty(String aKey, String aValue) {
}
/**
		 * 给打点设置多对属性对
		 * @param aProperties	多个属性对，如果key为null或空字符，会被自动丢弃掉。
		 * @return
		 */
		public UTHitBuilder setProperties(Map<String, String> aProperties) {
}
/**
		 * 获取指定的属性值
		 * @param aKey	属性key
		 * @return
		 */
		public String getProperty(String aKey) {
}
/**
		 * 构造打点需要的map，通过UTTracker发送
		 * @return
		 */
		public Map<String, String> build() {
}
}/**
	 * 自定义事件打点Builder
	 * @author daichenjie
	 * <pre>
	 * 自定义事件是除页面事件之外，几乎能满足用户的全部需求，可以用它来做abtest，也可以用它来记录各种效果数据。
	 * 自定义包含以下几个部分内容：
	 *    1.事件名称（event_label）
	 *    2.事件从开始到完成消耗的时长
	 *    3.事件所携带的属性
	 *    4.事件对应的页面
	 *    
	 * 例子：
	 *    // 事件名称：play_music
	 *    UTCustomHitBuilder lHitBuilder = new UTHitBuilders.UTCustomHitBuilder(
	 *			"play_music");
	 *    // 设置时长，3分钟，一首歌3分钟合理
	 *    lHitBuilder.setDurationOnEvent(3*60*1000);
	 *    // 设置关联的页面名称：聆听
	 *    lHitBuilder.setEventPage("Listen");
	 *    // 设置属性：类型摇滚
	 *    lHitBuilder.setProperty("type", "rock");
	 *    // 设置属性：歌曲标题
	 *    lHitBuilder.setProperty("title", "wonderful tonight");
     *    // 发送自定义事件打点
	 *    UTAnalytics.getInstance().getDefaultTracker().send(lHitBuilder.build());
	 *
	 * 结果log：
	 *    11-06 16:31:09.248: I/cache_log(14987): UT:省略...一堆||listener||19999||
	 *    play_music||-||180||type=rock,title=wonderful tonight
	 *    
	 *    这个Log里的19999代表自定义事件这个行为
	 *    
	 * </pre>
	 */
	public static class UTCustomHitBuilder extends UTHitBuilder {
/**
		 * 构造函数
		 * @param aEventLabel 	事件名称，唯一标识一个事件，在事件命名上，需要有区分性，避免不同团队写的名称碰撞
		 */
		public UTCustomHitBuilder(String aEventLabel) {
}
/**
		 * 设置事件消耗时长（事件完成时间-事件开始时间）
		 * @param aDuration	事件消耗时长（单位：毫秒）
		 * @return
		 */
		public UTCustomHitBuilder setDurationOnEvent(long aDuration) {
}
/**
		 * 设置自定义事件的页面字段
		 * 
		 * @param aPage 页面名称
		 * @return 
		 */
		public UTCustomHitBuilder setEventPage(String aPage) {
}
/**
		 * 进行URLEncoded转换(arg1不能被转换)
		 */
		@Override
		public Map<String, String> build() {
}
}/**
	 * 页面打点Builder
	 * @author daichenjie
	 * <pre>
	 * 页面打点是打点中最重要的事情。
	 * 这个类仅仅提供了页面打点的规范字段，这个类是我们SDK提供给App用来定制页面打点策略（如支持Fragment等）。
	 * 定制的内容包含以下内容：
	 *    1.当前页面页面名称
	 *    2.上一个访问页面
	 *    3.页面停留时长(页面消失时间-页面开始展示时间)
	 *    4.页面属性
	 *    
	 * 例子：
	 *    // 发送页面事件
	 *    UTPageHitBuilder lHitBuilder = new UTPageHitBuilder(lPageName);
	 *    lHitBuilder.setReferPage(lRefPage).setDurationOnPage(lPageStayConsume).setProperties(mPageProperties);
	 *	  UTTracker lTracker = UTAnalytics.getInstance().getDefaultTracker();
	 *    if(null != lTracker){
	 *        lTracker.send(lHitBuilder.build());
	 *    }
	 * </pre>
	 */
	public static class UTPageHitBuilder extends UTHitBuilder {
/**
		 * 构造函数
		 * @param aPageName 	页面名称，不能为空和null
		 */
		public UTPageHitBuilder(String aPageName) {
}
/**
		 * 设置当前页面的的上一个页面名称（上一个引导页面）
		 * @param aReferPage	上一个引导页面
		 * @return
		 */
		public UTPageHitBuilder setReferPage(String aReferPage) {
}
/**
		 * 设置页面停留时长（消失时间点-开始展示时间点）
		 * @param aDuration		停留时长（若是负数，sdk自动填充0）
		 * @return
		 */
		public UTPageHitBuilder setDurationOnPage(long aDuration) {
}

}

}
