/**
 * 页面打点辅助类
 * 
 * @author daichenjie 
 * <pre>
 * 
 * 页面采集包含以下几个元素：
 *    1.采集当前页面名称
 *    2.之前访问的页面（refer page）
 *    3.页面展示的时长
 *    4.页面的一些特性属性
 * 
 * 页面采集也间接的完成了，app在前台停留时长的这个指标及app启动次数。
 * 
 * 这个类的目标都在是让app开发者更少的使用UTPageHitBuilder，来完成页面的(展示、消失)打点，提高数据质量。
 * 
 * 说明：
 *    1.UTPageHitHelper主要完成Activity页面的采集，不包含Fragment，如果需要支持Fragment的，可以扩展当前类
 * 或者自己完成全部的逻辑，通过UTPageHitBuilder来完成规范要求的页面打点工作。
 *    2.UTPageHitHelper支持4.0及以上的版本的android系统，可以自动完成全部的工作，开发者不需要做任何activity
 * 的埋点，唯一的成本是，需要设置UTAnalytics.getInstance().setAppApplicationInstance(instance);
 *       
 *    那么4.0以下怎么办呢？
 *       1.如果用户的应用最少支持4.0到以上，那么不需要care，只需要按上述说明去做就可以
 *       2.如果用户的应用需要支持4.0以下的市场，那么应用方最好有一个activity的基类，基类中的onReasume、onPause
 *       按规范完成页面的打点。
 *       
 * 怎么用呢？
 *    1.4.0到以上
 *       UTAnalytics.getInstance().setAppApplicationInstance(instance)
 *    2.4.0以下
 *       activity的onReasume
 *           pageAppear(Activity aActivity)
 *       activity的onPause
 *           pageDisAppear(Activity aActivity)
 *           
 * updatePageProperties是一个什么玩意儿？
 *    举个例子：我们要开发一个购物的app，购物的app的宝贝展示页面，我们可能想要知道，宝贝展示页面，都展示了哪些商品呢？
 *            可以简单理解为，我们可以对采集的页面（GoodsDetails页面）记录上增加一个宝贝属性就可以，如item_id=xxxxxx
 *            我们可以通过sql，选择GoodsDetails页面就可以对其中的属性item_id做分析，就可以满足我们的需求。
 *            
 *    使用方法：
 *       // 这句话必须要在一个页面的onPause之前调用都可以
 *       Map<String, String> lMap = new HashMap<String, String>();
 *       lMap.put("item_id", "xxxxxx");
 *       UTPageHitHelper.getInstance().updatePageProperties(lMap);
 *       
 *       结果Log：
 *          11-06 16:10:32.088: I/cache_log(10879): UT:省略...一堆||Test||2001||-||-||3191||item_id=xxxxxx
 *       
 *          这里：2001是页面事件的ID，3191是页面展示的时长，item_id=xxxxxx就是属性
 *       
 *       特别强调：4.0以下updatePageProperties需要配合pageAppear和pageDisAppear使用
 *       
 * </pre>
 */
public class UTPageHitHelper {
/**
	 * 获取UTPageHitHelper实例
	 * @return
	 */
	public static UTPageHitHelper getInstance() {
}
/**
	 * 关闭页面自动采集功能
	 */
	public synchronized void turnOffAutoPageTrack(){
}
/**
	 * 页面展现
	 * @param aActivity	activity实例，在activity的onReasume中调用
	 */
	public synchronized void pageAppear(Activity aActivity) {
}
/**
	 * <p>更新页面属性，这个方法需要在当前Activity在前台的时候调用</p>
	 * <p>建议Activity实现IUTPageTrackProtocol，这种方式更安全</p>
	 * @param aProperties	属性
	 */
	public synchronized void updatePageProperties(
			Map<String, String> aProperties) {
}
/**
	 * 返回当前页面
	 * @return
	 */
	public synchronized String getCurrentPage() {
}
/**
	 * 页面消失
	 * @param aActivity	activity实例，在onpause中调用
	 */
	public synchronized void pageDisAppear(Activity aActivity) {
}

}
