/**
 * UT统计发送打点类
 * @author daichenjie
 * <pre>
 * 这个类主要完成把打点数据发送出去(send)。
 * 
 * 除了发送，还有如下几个公开方法：getGlobalProperty(String aKey)、removeGlobalProperty(String aKey)、
 * 							setGlobalProperty(String aKey, String aValue)
 * 那么这几个方法解决什么问题呢？
 *    先看一个例子：
 *       UTCustomHitBuilder lHitBuilder = new UTHitBuilders.UTCustomHitBuilder(
 *				"play_music");
 *       lHitBuilder.setProperty("type", "rock");
 *       lHitBuilder.setProperty("title", "wonderful tonight");
 *       //通过defaultTracker发送打点
 *       UTAnalytics.getInstance().getDefaultTracker().send(lHitBuilder.build());
 *       
 *       这里可以看出，Tracker发送的数据是lHitBuilder.build()，也就是一个Map<String,String>结构体。
 *       这几个方法就和这个Map结构体有关系：Global的含义就是这个特定Tracker每次send数据的时候，给build的Map都加上这些属性对
 *       
 *    怎么使用？
 *       //这里给DefaultTracker设定一个GlobalProperty
 *       UTAnalytics.getInstance().getDefaultTracker().setGlobalProperty("GlobalKey", "GlobalValue");
 *       //下面发送一个自定义事件打点，测试效果
 *       UTCustomHitBuilder lHitBuilder = new UTHitBuilders.UTCustomHitBuilder("TestGlobalKey");
 *       //发送数据
 *       UTAnalytics.getInstance().getDefaultTracker().send(lHitBuilder.build());
 *       
 *       结果如何？
 *          11-06 14:22:35.801: I/cache_log(455): UT:UT:省略...一堆||UT||19999
 *          ||TestGlobalKey||-||0||GlobalKey=GlobalValue
 *          
 *          这个自定义事件的末尾加了一个GlobalKey=GlobalValue的内容，就是这么神奇！
 *          
 *       getGlobalProperty和removeGlobalProperty：我想你懂的！
 * 
 * </pre>
 */
public class UTTracker {
/**
	 * 这个全局参数，这个Tracker中所有的打点，都会在args字段中带上这个属性。
	 * @param aKey		key，不能为空和null
	 * @param aValue	value，不能为null
	 */
	public synchronized void setGlobalProperty(String aKey, String aValue) {
}
/**
	 * 获取全局参数
	 * @param aKey
	 * @return
	 */
	public synchronized String getGlobalProperty(String aKey) {
}
/**
	 * 移除全局参数
	 * @param aKey
	 */
	public synchronized void removeGlobalProperty(String aKey) {
}
/**
	 * 去除换行符以及双竖线
	 * 
	 * @param pStr
	 * @return
	 */
	private static String _getStringNoBlankAndDLine(String pStr) {
		if (pStr != null && !"".equals(pStr)) {

			Matcher m = s_p.matcher(pStr);
			String strNoBlank = m.replaceAll("");
			
			return strNoBlank;

		}
		return pStr;
	}

	private static String _checkField(String pField) {
		pField = _getStringNoBlankAndDLine(pField);
		return pField;
	}
	
	private Map<String, String> _checkMapFields(Map<String, String> aLogMap){
		if(null != aLogMap){
			Map<String,String> lNewMap = new HashMap<String, String>();
			Iterator<String> lKeyItor = aLogMap.keySet().iterator();
			if(null != lKeyItor){
				while(lKeyItor.hasNext()){
					String lKey = lKeyItor.next();
					if(null != lKey){
						String lValue = _checkField(aLogMap.get(lKey));
						lNewMap.put(lKey, lValue);
					}
				}
			}
			return lNewMap;
		}
		return null;
	}
	
	/**
	 * 发送打点
	 * @param aLogMap	打点的元数据，需要通过UTHitBuilder的子类的build方法去生成
	 */
	public void send(Map<String, String> aLogMap) {
}

}
